@@ -27,21 +27,21 @@
 
 #include <libkipi/plugin.h>
 
-class KAction;
+class TDEAction;
 
 using namespace KIPIFlickrExportPlugin;
 
 class Plugin_FlickrExport : public KIPI::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
 
     Plugin_FlickrExport(TQObject *parent, const char* name, const TQStringList &args);
     ~Plugin_FlickrExport();
 
-    virtual KIPI::Category category(KAction* action) const;
+    virtual KIPI::Category category(TDEAction* action) const;
     virtual void setup(TQWidget*);
 
 public slots:
@@ -50,7 +50,7 @@ public slots:
 
 private:
 
-    KAction      *m_action;
+    TDEAction      *m_action;
     FlickrWindow *m_dlg;
 };
 
