@@ -33,18 +33,18 @@
 
 // Include files for KDE
 
-#include <kaboutdata.h>
+#include <tdeaboutdata.h>
 #include <khelpmenu.h>
-#include <kpopupmenu.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kapplication.h>
+#include <tdepopupmenu.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
-#include <khtml_part.h>
-#include <khtmlview.h>
+#include <tdehtml_part.h>
+#include <tdehtmlview.h>
 #include <krun.h>
 #include <kdebug.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 
 // KIPI include files
 
@@ -80,7 +80,7 @@ GalleryWindow::GalleryWindow(KIPI::Interface* interface, TQWidget *parent, Galle
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Gallery Export"),
                                            0,
-                                           KAboutData::License_GPL,
+                                           TDEAboutData::License_GPL,
                                            I18N_NOOP("A Kipi plugin to export image collection to remote Gallery server."),
                                            "(c) 2003-2005, Renchi Raju");
 
@@ -130,7 +130,7 @@ GalleryWindow::GalleryWindow(KIPI::Interface* interface, TQWidget *parent, Galle
     connect(m_addPhotoBtn, TQT_SIGNAL(clicked()), TQT_SLOT( slotAddPhotos()));
 
     // read config
-    KConfig config("kipirc");
+    TDEConfig config("kipirc");
     config.setGroup("GallerySync Settings");
 
     m_talker = new GalleryTalker( this );
@@ -178,7 +178,7 @@ GalleryWindow::GalleryWindow(KIPI::Interface* interface, TQWidget *parent, Galle
 GalleryWindow::~GalleryWindow()
 {
     // write config
-    KConfig config("kipirc");
+    TDEConfig config("kipirc");
     config.setGroup("GallerySync Settings");
     config.writeEntry("Resize", m_resizeCheckBox->isChecked());
     config.writeEntry("Set title", m_captTitleCheckBox->isChecked());
@@ -192,7 +192,7 @@ GalleryWindow::~GalleryWindow()
 
 void GalleryWindow::slotHelp()
 {
-    KApplication::kApplication()->invokeHelp("galleryexport", "kipi-plugins");
+    TDEApplication::kApplication()->invokeHelp("galleryexport", "kipi-plugins");
 }
 
 void GalleryWindow::slotDoLogin()
@@ -282,8 +282,8 @@ void GalleryWindow::slotAlbums( const TQValueList<GAlbum>& albumList )
     m_photoView->write( "<html></html>" );
     m_photoView->end();
 
-    KIconLoader* iconLoader = KApplication::kApplication()->iconLoader();
-    TQPixmap pix = iconLoader->loadIcon( "folder", KIcon::NoGroup, 32 );
+    TDEIconLoader* iconLoader = TDEApplication::kApplication()->iconLoader();
+    TQPixmap pix = iconLoader->loadIcon( "folder", TDEIcon::NoGroup, 32 );
 
     typedef TQValueList<GAlbum> GAlbumList;
     GAlbumList::const_iterator iter;
