@@ -34,7 +34,7 @@
 
 // KDE includes.
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdialog.h>
 #include <knuminput.h>
 #include <klineedit.h>
